@@ -28,7 +28,7 @@
  * Collection of Octopi constants and enums
  */
 
-const QString ctn_APPLICATION_VERSION(QStringLiteral("0.17.0"));
+const QString ctn_APPLICATION_VERSION(QStringLiteral("0.18.0"));
 
 //MainWindow related
 enum SystemUpgradeOptions { ectn_NO_OPT, ectn_SYNC_DATABASE_OPT, ectn_NOCONFIRM_OPT };
@@ -83,6 +83,8 @@ enum Language { ectn_LANG_ENGLISH, ectn_LANG_USER_DEFINED };
 enum TreatString { ectn_TREAT_STRING, ectn_DONT_TREAT_STRING };
 enum TreatURLLinks { ectn_TREAT_URL_LINK, ectn_DONT_TREAT_URL_LINK };
 
+enum SearchMethod { ectn_SEARCH_BY_NAME, ectn_SEARCH_BY_DESCRIPTION };
+
 //SettingsManager - Octopi related
 enum SaveSettingsReason { ectn_AUR_PACKAGELIST, ectn_PACKAGELIST, ectn_CURRENTTABINDEX, ectn_NORMAL=30,
                           ectn_MAXIMIZE_PACKAGES=40, ectn_MAXIMIZE_PROPERTIES=50, ectn_GROUPS=5, ectn_CONSOLE_FONT_SIZE };
@@ -103,6 +105,7 @@ const QString ctn_KEY_AUR_EDITMENU_PARAM(QStringLiteral("Aur_EditMenu_Param"));
 const QString ctn_KEY_AUR_BUILDDIR(QStringLiteral("Aur_Builddir"));
 const QString ctn_KEY_SEARCH_OUTDATED_AUR_PACKAGES(QStringLiteral("Search_Outdated_Aur_Packages"));
 const QString ctn_KEY_ENABLE_AUR_VOTING(QStringLiteral("Enable_Aur_Voting"));
+const QString ctn_KEY_ENABLE_PACKAGE_TOOLTIPS(QStringLiteral("Enable_Package_Tooltips"));
 const QString ctn_KEY_AUR_USERNAME(QStringLiteral("Aur_Username"));
 const QString ctn_KEY_AUR_PASSWORD(QStringLiteral("Aur_Password"));
 const QString ctn_KEY_USE_ALTERNATE_ROW_COLOR(QStringLiteral("Use_Alternate_Row_Color"));
@@ -138,6 +141,7 @@ const QString ctn_KEY_PACKAGE_BUILD_DATE_COLUMN_WITH(QStringLiteral("Package_Bui
 const QString ctn_KEY_PACKAGE_INSTALL_DATE_COLUMN_WITH(QStringLiteral("Package_Install_Date_Column_Width"));
 const QString ctn_KEY_PACKAGE_INSTALL_REASON_COLUMN_WITH(QStringLiteral("Package_Install_Reason_Column_Width"));
 const QString ctn_KEY_PLAY_BELL_SOUND_ON_TERMINAL_PASSWORD_INPUT(QStringLiteral("Play_Bell_Sound_On_Terminal_Password_Input"));
+const QString ctn_KEY_SEARCH_METHOD(QStringLiteral("Search_Method"));
 const QString ctn_KEY_SHOW_PACKAGE_LICENSES_COLUMN(QStringLiteral("Show_Package_Licenses_Column"));
 const QString ctn_KEY_SHOW_PACKAGE_INSTALLED_SIZE_COLUMN(QStringLiteral("Show_Package_Installed_Size_Column"));
 const QString ctn_KEY_SHOW_PACKAGE_BUILD_DATE_COLUMN(QStringLiteral("Show_Package_Build_Date_Column"));
@@ -148,6 +152,7 @@ const QString ctn_KEY_TERMINAL(QStringLiteral("Terminal"));
 const QString ctn_KEY_TERMINAL_COLOR_SCHEME(QStringLiteral("Terminal_Color_Scheme"));
 const QString ctn_KEY_TERMINAL_FONT_FAMILY(QStringLiteral("Terminal_Font_Family"));
 const QString ctn_KEY_TERMINAL_FONT_POINT_SIZE(QStringLiteral("Terminal_Font_Point_Size"));
+const QString ctn_KEY_TERMINAL_FORCE_BASH_SHELL(QStringLiteral("Terminal_Force_Bash_Shell"));
 const QString ctn_KEY_INSTANT_SEARCH(QStringLiteral("Instant_Search"));
 const QString ctn_KEY_PROXY_SETTINGS(QStringLiteral("Proxy_Settings"));
 const QString ctn_AUTOMATIC(QStringLiteral("automatic"));
@@ -177,10 +182,12 @@ const QString ctn_PACMAN_CORE_DB_FILE = QStringLiteral("/var/lib/pacman/sync/cor
 //ARTIX MAIN DB FILE
 const QString ctn_PACMAN_SYSTEM_DB_FILE = QStringLiteral("/var/lib/pacman/sync/system.db");
 
-enum PackageStatus { ectn_INSTALLED, ectn_NON_INSTALLED, ectn_OUTDATED, ectn_NEWER,
-                     ectn_FOREIGN, ectn_FOREIGN_OUTDATED };
+enum PackageStatus { ectn_IGNORED, ectn_INSTALLED, ectn_NON_INSTALLED,
+                     ectn_OUTDATED, ectn_NEWER, ectn_FOREIGN, ectn_FOREIGN_OUTDATED };
 
-enum ViewOptions { ectn_ALL_PKGS, ectn_INSTALLED_PKGS, ectn_NON_INSTALLED_PKGS, ectn_OUTDATED_PKGS };
+enum ViewOptions { ectn_ALL_PKGS, ectn_IGNORED_PKGS, ectn_INSTALLED_PKGS, ectn_NON_INSTALLED_PKGS, ectn_OUTDATED_PKGS };
+
+const QString ctn_BASH_SHELL(QStringLiteral("/usr/bin/bash"));
 
 //Supported AUR user base package tools
 const QString ctn_PACAUR_TOOL(QStringLiteral("pacaur"));
