@@ -166,6 +166,7 @@ private:
   CommandExecuting m_commandExecuting;
   CommandExecuting m_commandQueued;
 
+  QSet<QString> *m_ignoredStringList;
   QStringList m_lastCommandList; //This member holds the last command string executed by Octopi
   QStringList *m_outdatedStringList;
   QStringList *m_checkupdatesStringList; //This is the outdated pkg list retrieved by checkupdates
@@ -191,6 +192,7 @@ private:
   QTimer *m_outdatedAURTimer;
 
   QAction *m_dummyAction;
+  QAction *m_savedSearchMethod;
   QAction *m_actionLastSearchMethod;
   QAction *m_actionPackageInfo;
   QAction *m_actionInstallPacmanUpdates;
@@ -209,6 +211,7 @@ private:
   QAction *m_actionAUROpenPKGBUILD;
   QAction *m_actionAURShowPKGBUILDDiff;
   QAction *m_actionChangeInstallReason;
+  QAction *m_actionPacmanKey;
   QToolButton *m_toolButtonStopTransaction;
 
   //Toggles use of AUR tool
@@ -344,6 +347,8 @@ private slots:
   void onExecCommandInTabTerminal(QString command);
   void onPressAnyKeyToContinue();
   void onCancelControlKey();
+  void onAddToIgnored();
+  void onRemoveFromIgnored();
   void initToolButtonPacman();
   void initToolButtonAUR();
   void showToolButtonAUR();
@@ -432,6 +437,7 @@ private slots:
   void doInstallAURPackage();
   void doPreDownloadTempYay();
   void doInstallYayPackage();
+  void doRefreshPacmanKeys();
   void doRemoveAUR();
   void doRemoveAURPackage();
   void doRemoveAndInstallAUR();
@@ -460,6 +466,7 @@ private slots:
 
   //View menu and submenu Repository actions...
   void selectedAllPackagesMenu();
+  void selectedIgnoredPackagesMenu();
   void selectedInstalledPackagesMenu();
   void selectedNonInstalledPackagesMenu();
   void selectedOutdatedPackagesMenu();
