@@ -290,6 +290,7 @@ void MainWindow::initMenuBar()
   ui->actionViewAllPackages->setText(StrConstants::getAll());
 
   actionGroupPackages->addAction(ui->actionViewAllPackages);
+  actionGroupPackages->addAction(ui->actionViewIgnoredPackages);
   actionGroupPackages->addAction(ui->actionViewInstalledPackages);
   actionGroupPackages->addAction(ui->actionViewNonInstalledPackages);
   actionGroupPackages->addAction(ui->actionViewOutdated);
@@ -490,6 +491,9 @@ void MainWindow::initTabWidgetPropertiesIndex()
  */
 void MainWindow::initTabActions()
 {
+  ui->twProperties->setActionApply(ui->actionApply);
+  ui->twProperties->setActionCancel(ui->actionCancel);
+  ui->twProperties->setActionGetNews(ui->actionGetNews);
   ui->twProperties->initTabActions();
 
   connect(ui->twProperties->getTvTransaction(), SIGNAL(customContextMenuRequested(QPoint)),
@@ -678,6 +682,11 @@ void MainWindow::initActions()
   m_actionPackageInfo = new QAction(this);
   m_actionPackageInfo->setText(StrConstants::getTabInfoName());
 
+  m_actionPacmanKey = new QAction(this);
+  m_actionPacmanKey->setIcon(IconHelper::getIconKeys());
+  m_actionPacmanKey->setText(QStringLiteral("Pacman-key..."));
+  connect(m_actionPacmanKey, SIGNAL(triggered(bool)), this, SLOT(doRefreshPacmanKeys()));
+
   m_actionAURVote = new QAction(this);
   m_actionAURVote->setText(StrConstants::getVote());
   m_actionAURVote->setIcon(IconHelper::getIconVote());
@@ -766,9 +775,22 @@ void MainWindow::initActions()
   actionGroup->addAction(ui->actionSearchByDescription);
   actionGroup->addAction(ui->actionSearchByName);
   actionGroup->addAction(ui->actionSearchByFile);
-  ui->actionSearchByName->setChecked(true);
-  m_actionLastSearchMethod = ui->actionSearchByName;
   actionGroup->setExclusive(true);
+
+  uint sm = SettingsManager::getSearchMethod();
+  if (sm == 0)
+  {
+    ui->actionSearchByName->setChecked(true);
+    m_actionLastSearchMethod = ui->actionSearchByName;
+  }
+  else if (sm == 1)
+  {
+    ui->actionSearchByDescription->setChecked(true);
+    m_actionLastSearchMethod = ui->actionSearchByDescription;
+  }
+
+  //m_savedSearchMethod = nullptr;
+  m_savedSearchMethod = m_actionLastSearchMethod;
   connect(actionGroup, SIGNAL(triggered(QAction*)), this, SLOT(tvPackagesSearchColumnChanged(QAction*)));
 
   ui->actionInstallLocalPackage->setIcon(IconHelper::getIconFolder());
@@ -789,6 +811,8 @@ void MainWindow::initActions()
   connect(ui->actionSystemUpgrade, SIGNAL(triggered()), this, SLOT(doSystemUpgrade()));
   connect(ui->actionRemove, SIGNAL(triggered()), this, SLOT(insertIntoRemovePackage()));
   connect(ui->actionInstall, SIGNAL(triggered()), this, SLOT(insertIntoInstallPackage()));
+  connect(ui->actionAddToIgnored, SIGNAL(triggered()), this, SLOT(onAddToIgnored()));
+  connect(ui->actionRemoveFromIgnored, SIGNAL(triggered()), this, SLOT(onRemoveFromIgnored()));
   connect(ui->actionInstallAUR, SIGNAL(triggered()), this, SLOT(doInstallAURPackage()));
   connect(ui->actionFindFileInPackage, SIGNAL(triggered()), this, SLOT(findFileInPackage()));
   connect(ui->actionRemoveGroup, SIGNAL(triggered()), this, SLOT(insertGroupIntoRemovePackage()));
@@ -840,6 +864,7 @@ void MainWindow::initActions()
 
   // Actions for the View menu
   connect(ui->actionViewAllPackages, SIGNAL(triggered()), this, SLOT(selectedAllPackagesMenu()));
+  connect(ui->actionViewIgnoredPackages, SIGNAL(triggered()), this, SLOT(selectedIgnoredPackagesMenu()));
   connect(ui->actionViewInstalledPackages, SIGNAL(triggered()), this, SLOT(selectedInstalledPackagesMenu()));
   connect(ui->actionViewNonInstalledPackages, SIGNAL(triggered()), this, SLOT(selectedNonInstalledPackagesMenu()));
   connect(ui->actionViewOutdated, SIGNAL(triggered()), this, SLOT(selectedOutdatedPackagesMenu()));
