@@ -139,6 +139,8 @@ void MainWindow::refreshMenuTools()
   {
     static bool connectorSysInfo=false;
 
+    ui->menuTools->addAction(m_actionPacmanKey);
+
     ui->menuTools->addSeparator();
     m_actionSysInfo->setText(QStringLiteral("SysInfo..."));
     ui->menuTools->addAction(m_actionSysInfo);
@@ -171,9 +173,13 @@ void MainWindow::refreshGroupsWidget()
   items.append(new QTreeWidgetItem(static_cast<QTreeWidget*>(nullptr), QStringList(QLatin1Char('<') + StrConstants::getDisplayAllGroups() + QLatin1Char('>'))));
   m_AllGroupsItem = items.at(0);
   const QStringList*const packageGroups = Package::getPackageGroups();
+  QTreeWidgetItem *twi;
+
   for(const QString& group: *packageGroups)
   {
-    items.append(new QTreeWidgetItem(static_cast<QTreeWidget*>(nullptr), QStringList(group)));
+    twi = new QTreeWidgetItem(static_cast<QTreeWidget*>(nullptr), QStringList(group));
+    twi->setIcon(0, IconHelper::getIconGroup());
+    items.append(twi);
   }
   m_packageRepo.checkAndSetGroups(*packageGroups); // update Package Repository as well
   delete packageGroups;
@@ -463,7 +469,7 @@ void MainWindow::retrieveForeignPackageList()
 {
   QEventLoop el;
   QFuture<QList<PackageListData> *> f;
-  f = QtConcurrent::run(searchForeignPackages);
+  f = QtConcurrent::run(searchForeignPackages, m_ignoredStringList);
   connect(&g_fwForeignPacman, SIGNAL(finished()), this, SLOT(preBuildForeignPackageList()));
   connect(&g_fwForeignPacman, SIGNAL(finished()), &el, SLOT(quit()));
   g_fwForeignPacman.setFuture(f);
@@ -597,9 +603,10 @@ void MainWindow::metaBuildPackageList()
 
   //Here we build the list of all available packages
   if (ui->twGroups->topLevelItemCount() == 0 || isAllGroupsSelected())
-  {        
+  {
     ui->actionSearchByFile->setEnabled(true);
     //ui->actionSearchByName->setChecked(true);
+
     m_actionLastSearchMethod->setChecked(true);
     if (ui->actionSearchByFile->isChecked()) m_leFilterPackage->setRefreshValidator(ectn_FILE_VALIDATOR);
     else if (ui->actionSearchByName->isChecked()) m_leFilterPackage->setRefreshValidator(ectn_DEFAULT_VALIDATOR);
@@ -794,6 +801,12 @@ void MainWindow::buildPackageList()
     if (m_numberOfOutdatedPackages == 0 && m_checkupdatesStringList->count() > 0)
       m_numberOfOutdatedPackages = m_checkupdatesStringList->count();
 
+    m_ignoredStringList->clear();
+    delete m_ignoredStringList;
+    m_ignoredStringList = nullptr;
+
+    m_ignoredStringList = Package::extractIgnorePkgList();
+
     m_unrequiredPackageList->clear();
     delete m_unrequiredPackageList;
     m_unrequiredPackageList = nullptr;
@@ -822,7 +835,7 @@ void MainWindow::buildPackageList()
       delete m_foreignPackageList;
       m_foreignPackageList = nullptr;
 
-      m_foreignPackageList = markForeignPackagesInPkgList(m_hasForeignTool, m_outdatedAURStringList);
+      m_foreignPackageList = markForeignPackagesInPkgList(m_hasForeignTool, m_outdatedAURStringList, m_ignoredStringList);
 
       list->append(*m_foreignPackageList);
 
@@ -852,7 +865,7 @@ void MainWindow::buildPackageList()
   m_progressWidget->setValue(counter);
   m_progressWidget->close();
 
-  m_packageRepo.setData(list, *m_unrequiredPackageList);
+  m_packageRepo.setData(list, *m_unrequiredPackageList, *m_ignoredStringList);
 
   if (ui->tvPackages->model() != m_packageModel.get())
   {
@@ -1068,7 +1081,7 @@ void MainWindow::postRefreshOutdatedAURStringList()
   m_foreignPackageList->clear();
   delete m_foreignPackageList;
   m_foreignPackageList = nullptr;
-  m_foreignPackageList = markForeignPackagesInPkgList(m_hasForeignTool, m_outdatedAURStringList);
+  m_foreignPackageList = markForeignPackagesInPkgList(m_hasForeignTool, m_outdatedAURStringList, m_ignoredStringList);
 
   LinuxDistro distro = UnixCommand::getLinuxDistro();
   if (distro != ectn_KAOS && isAURGroupSelected()) return;
@@ -1683,12 +1696,16 @@ void MainWindow::refreshTabFiles(bool clearContents, bool neverQuit)
   if (tvPkgFileList)
   {
     QString pkgName = package->name;
+
     QStandardItemModel *fakeModelPkgFileList = new QStandardItemModel(this);
+
     QStandardItemModel *modelPkgFileList = qobject_cast<QStandardItemModel*>(tvPkgFileList->model());
     modelPkgFileList->clear();
 
     QStandardItem *fakeRoot = fakeModelPkgFileList->invisibleRootItem();
+
     QStandardItem *root = modelPkgFileList->invisibleRootItem();
+
     QStandardItem *lastDir, *item, *lastItem=root, *parent;
     bool first=true;
     lastDir = root;
@@ -1829,9 +1846,11 @@ void MainWindow::refreshTabFiles(bool clearContents, bool neverQuit)
     }
 
     m_progressWidget->close();
+
     root = fakeRoot;
     fakeModelPkgFileList->sort(0);
     modelPkgFileList = fakeModelPkgFileList;
+
     tvPkgFileList->setModel(modelPkgFileList);
     tvPkgFileList->header()->setDefaultAlignment( Qt::AlignCenter );
     modelPkgFileList->setHorizontalHeaderLabels( QStringList() << StrConstants::getContentsOf().arg(pkgName));
@@ -1945,7 +1964,7 @@ void MainWindow::lightPackageFilter()
 }
 
 /*
- * Whenever user selects View/All we show him all the available packages
+ * Whenever user selects View/All we show him all the ignored packages
  */
 void MainWindow::selectedAllPackagesMenu()
 {  
@@ -1953,6 +1972,15 @@ void MainWindow::selectedAllPackagesMenu()
   changePackageListModel(ectn_ALL_PKGS, m_selectedRepository);
 }
 
+/*
+ * Whenever user selects View/Installed we show him only the installed packages
+ */
+void MainWindow::selectedIgnoredPackagesMenu()
+{
+  m_selectedViewOption = ectn_IGNORED_PKGS;
+  changePackageListModel(ectn_IGNORED_PKGS, m_selectedRepository);
+}
+
 /*
  * Whenever user selects View/Installed we show him only the installed packages
  */
