@@ -402,6 +402,55 @@ void MainWindow::doChangeInstallReason(const QHash<QString, QString> &listOfTarg
   m_pacmanExec->doChangeInstallReason(listOfTargets);
 }
 
+/*
+ * Adds selected package to the IgnorePkg section of /etc/pacman.conf
+ */
+void MainWindow::onAddToIgnored()
+{
+  qApp->processEvents(); 
+  QModelIndexList selectedRows;
+  selectedRows = ui->tvPackages->selectionModel()->selectedRows();
+
+  for(QModelIndex item: std::as_const(selectedRows))
+  {
+    const PackageRepository::PackageData*const package = m_packageModel->getData(item);
+    if (package == nullptr) {
+      assert(false);
+      continue;
+    }
+
+    m_ignoredStringList->insert(package->name);
+  }
+
+  Package::updateIgnorePkgSection(m_ignoredStringList);
+  metaBuildPackageList();
+}
+
+/*
+ * Removes selected package from the IgnorePkg section of /etc/pacman.conf
+ */
+void MainWindow::onRemoveFromIgnored()
+{
+  qApp->processEvents();
+  QModelIndexList selectedRows;
+  selectedRows = ui->tvPackages->selectionModel()->selectedRows();
+
+  for(QModelIndex item: std::as_const(selectedRows))
+  {
+    const PackageRepository::PackageData*const package = m_packageModel->getData(item);
+    if (package == nullptr) {
+      assert(false);
+      continue;
+    }
+
+    if (m_ignoredStringList->contains(package->name))
+      m_ignoredStringList->remove(package->name);
+  }
+
+  Package::updateIgnorePkgSection(m_ignoredStringList);
+  metaBuildPackageList();
+}
+
 /*
  * Inserts the current selected packages for installation into the Transaction Treeview
  * This is the SLOT, it needs to call insertInstallPackageIntoTransaction(PackageName) to work!
@@ -410,45 +459,37 @@ void MainWindow::insertIntoInstallPackage(QModelIndex *indexToInclude)
 {
   qApp->processEvents();
 
-  //if (!isAURGroupSelected())
+  QModelIndexList selectedRows;
+
+  if (indexToInclude == nullptr)
+    selectedRows = ui->tvPackages->selectionModel()->selectedRows();
+  else
   {
-    //ensureTabVisible(ctn_TABINDEX_ACTIONS);
-    QModelIndexList selectedRows;
+    selectedRows.append(*indexToInclude);
+  }
 
-    if (indexToInclude == nullptr)
-      selectedRows = ui->tvPackages->selectionModel()->selectedRows();
-    else
+  //First, let's see if we are dealing with a package group
+  if(!isAURGroupSelected() && !isAllGroupsSelected())
+  {
+    //If we are trying to insert all the group's packages, why not insert the entire group?
+    if(selectedRows.count() == m_packageModel->getPackageCount())
     {
-      selectedRows.append(*indexToInclude);
-    }
-
-    //First, let's see if we are dealing with a package group    
-    if(!isAURGroupSelected() && !isAllGroupsSelected())
-    {
-      //If we are trying to insert all the group's packages, why not insert the entire group?
-      if(selectedRows.count() == m_packageModel->getPackageCount())
-      {
-        insertInstallPackageIntoTransaction(getSelectedGroup());
-        return;
-      }
-    }
-
-    for(QModelIndex item: std::as_const(selectedRows))
-    {
-      const PackageRepository::PackageData*const package = m_packageModel->getData(item);
-      if (package == nullptr) {
-        assert(false);
-        continue;
-      }
-
-      insertIntoInstallPackageOptDeps(package->name); //Do we have any deps???
-      insertInstallPackageIntoTransaction(package->repository + QLatin1Char('/') + package->name);
+      insertInstallPackageIntoTransaction(getSelectedGroup());
+      return;
     }
   }
-  /*else
+
+  for(QModelIndex item: std::as_const(selectedRows))
   {
-    doInstallAURPackage();
-  }*/
+    const PackageRepository::PackageData*const package = m_packageModel->getData(item);
+    if (package == nullptr) {
+      assert(false);
+      continue;
+    }
+
+    insertIntoInstallPackageOptDeps(package->name); //Do we have any deps???
+    insertInstallPackageIntoTransaction(package->repository + QLatin1Char('/') + package->name);
+  }
 }
 
 /*
@@ -651,7 +692,9 @@ void MainWindow::tvTransactionSelectionChanged(const QItemSelection&, const QIte
  */
 void MainWindow::tvTransactionRowsChanged(const QModelIndex& parent)
 {
-  //QStandardItem *item = m_modelTransaction->itemFromIndex(parent);
+  if (m_commandExecuting == ectn_NONE)
+    ensureTabVisible(ctn_TABINDEX_ACTIONS);
+
   QStandardItem *item = ui->twProperties->getModelTransaction()->itemFromIndex(parent);
   QString count = QString::number(item->rowCount());
   QStandardItem * itemRemove = getRemoveTransactionParentItem();
@@ -982,7 +1025,9 @@ void MainWindow::doSystemUpgrade(SystemUpgradeOptions systemUpgradeOptions)
 
   if(!isInternetAvailable()) return;
 
-  if(SettingsManager::getAlwaysUseTheTerminal() || !SettingsManager::getEnableConfirmationDialogInSysUpgrade())
+  bool isGarudaLinux = UnixCommand::getLinuxDistro() == ectn_GARUDALINUX;
+
+  if(isGarudaLinux || SettingsManager::getAlwaysUseTheTerminal() || !SettingsManager::getEnableConfirmationDialogInSysUpgrade())
   {
     int res = prepareSystemUpgrade();
     if (!res)
@@ -992,7 +1037,7 @@ void MainWindow::doSystemUpgrade(SystemUpgradeOptions systemUpgradeOptions)
       return;
     }
 
-    if( SettingsManager::getAlwaysUseTheTerminal() || (m_checkupdatesStringList->count() != 0 && m_checkupdatesStringList->contains(QStringLiteral("pacman"))) ||
+    if(isGarudaLinux || SettingsManager::getAlwaysUseTheTerminal() || (m_checkupdatesStringList->count() != 0 && m_checkupdatesStringList->contains(QStringLiteral("pacman"))) ||
         (m_outdatedStringList->count() != 0 && m_outdatedStringList->contains(QStringLiteral("pacman"))) )
     {
       m_commandExecuting = ectn_RUN_SYSTEM_UPGRADE_IN_TERMINAL;
@@ -1237,9 +1282,6 @@ void MainWindow::doRemoveAndInstall()
                          QLatin1String("</b><br>"), ectn_DONT_TREAT_URL_LINK);
 
     disableTransactionActions();
-    //m_progressWidget->setValue(0);
-    //m_progressWidget->setMaximum(100);
-    //clearTabOutput();
 
     m_pacmanExec = new PacmanExec();
     m_pacmanExec->setSharedMemory(m_sharedMemory);
@@ -1248,9 +1290,6 @@ void MainWindow::doRemoveAndInstall()
     QObject::connect(m_pacmanExec, SIGNAL(finished(int, QProcess::ExitStatus)),
                      this, SLOT( pacmanProcessFinished(int, QProcess::ExitStatus) ));
 
-    //QObject::connect(m_pacmanExec, SIGNAL(percentage(int)), this, SLOT(incrementPercentage(int)));
-    //QObject::connect(m_pacmanExec, SIGNAL(textToPrintExt(QString)), this, SLOT(outputText(QString)));
-    //QObject::connect(m_pacmanExec, SIGNAL(canStopTransaction(bool)), this, SLOT(onCanStopTransaction(bool)));
     QObject::connect(m_pacmanExec, SIGNAL(commandToExecInQTermWidget(QString)), this, SLOT(onExecCommandInTabTerminal(QString)));
 
     m_commandExecuting = ectn_RUN_IN_TERMINAL;
@@ -1365,6 +1404,31 @@ void MainWindow::doRemoveAndInstall()
   }
 }
 
+/*
+ * Calls pacman-key to refresh packager gpg keys
+ */
+void MainWindow::doRefreshPacmanKeys()
+{
+  disableTransactionActions();
+  m_progressWidget->setValue(0);
+  m_progressWidget->setMaximum(100);
+  clearTabOutput();
+
+  m_pacmanExec = new PacmanExec();
+  m_pacmanExec->setSharedMemory(m_sharedMemory);
+  if (m_debugInfo) m_pacmanExec->setDebugMode(true);
+
+  QObject::connect(m_pacmanExec, SIGNAL(finished (int,QProcess::ExitStatus)),
+                   this, SLOT( pacmanProcessFinished(int,QProcess::ExitStatus) ));
+
+  QObject::connect(m_pacmanExec, SIGNAL(percentage(int)), this, SLOT(incrementPercentage(int)));
+  QObject::connect(m_pacmanExec, SIGNAL(textToPrintExt(QString)), this, SLOT(outputText(QString)));
+  QObject::connect(m_pacmanExec, SIGNAL(commandToExecInQTermWidget(QString)), this, SLOT(onExecCommandInTabTerminal(QString)));
+
+  m_commandExecuting = ectn_RUN_IN_TERMINAL;
+  m_pacmanExec->doRefreshPacmanKeys();
+}
+
 /*
  * Removes ALL the packages selected by the user with "pacman -Rcs (CASCADE)" !
  */
@@ -1391,7 +1455,6 @@ void MainWindow::doRemove()
                          QLatin1String("</b><br>"), ectn_DONT_TREAT_URL_LINK);
 
     disableTransactionActions();
-    //clearTabOutput();
 
     m_pacmanExec = new PacmanExec();
     m_pacmanExec->setSharedMemory(m_sharedMemory);
@@ -1400,9 +1463,6 @@ void MainWindow::doRemove()
     QObject::connect(m_pacmanExec, SIGNAL(finished (int, QProcess::ExitStatus)),
                      this, SLOT( pacmanProcessFinished(int, QProcess::ExitStatus) ));
 
-    //QObject::connect(m_pacmanExec, SIGNAL(percentage(int)), this, SLOT(incrementPercentage(int)));
-    //QObject::connect(m_pacmanExec, SIGNAL(textToPrintExt(QString)), this, SLOT(outputText(QString)));
-    //QObject::connect(m_pacmanExec, SIGNAL(canStopTransaction(bool)), this, SLOT(onCanStopTransaction(bool)));
     QObject::connect(m_pacmanExec, SIGNAL(commandToExecInQTermWidget(QString)), this, SLOT(onExecCommandInTabTerminal(QString)));
 
     m_commandExecuting = ectn_RUN_IN_TERMINAL;
@@ -1590,7 +1650,6 @@ void MainWindow::doInstallYayPackage()
 void MainWindow::doRemoveAUR()
 {
   QString listOfTargets = getTobeRemovedPackages();
-  //listOfTargets = listToBeInst.keys().join(QStringLiteral(" "));
   listOfTargets.replace(StrConstants::getForeignRepositoryGroupName() + QLatin1Char('/'), QStringLiteral(""));
 
   disableTransactionActions();
@@ -1677,7 +1736,6 @@ void MainWindow::onAURToolChanged()
       static QStandardItemModel emptyModel;
       ui->tvPackages->setModel(&emptyModel);
       removePackageTreeViewConnections();
-      //m_actionSwitchToAURTool->setEnabled(false);
       m_refreshForeignPackageList = true;
       m_actionMenuRepository->setEnabled(true);
       ui->twGroups->setEnabled(true);
@@ -1711,7 +1769,6 @@ void MainWindow::onAURToolChanged()
     }
 
     m_hasForeignTool = false;
-    //m_actionSwitchToAURTool->setVisible(false);
     m_refreshForeignPackageList = false;
     m_outdatedAURPackagesNameVersion->clear();
     m_outdatedAURStringList->clear();
@@ -1727,7 +1784,6 @@ void MainWindow::onAURToolChanged()
 
     if (!isAURGroupSelected())
     {
-      //m_actionSwitchToAURTool->setVisible(true);
       m_actionSwitchToForeignTool->setCheckable(true);
       m_actionSwitchToForeignTool->setChecked(false);
     }
@@ -1837,8 +1893,6 @@ void MainWindow::doInstallAUR()
 
   m_commandExecuting = ectn_RUN_IN_TERMINAL;
   m_pacmanExec->doAURInstall(listOfTargets);
-
-  //QMessageBox::warning(this, StrConstants::getApplicationName(), listOfTargets);
 }
 
 /*
@@ -1881,9 +1935,6 @@ void MainWindow::doInstall()
     writeToTabOutput(QLatin1String("<b>") + StrConstants::getCommandFinishedOK() +
                          QLatin1String("</b><br>"), ectn_DONT_TREAT_URL_LINK);
     disableTransactionActions();
-    //m_progressWidget->setValue(0);
-    //m_progressWidget->setMaximum(100);
-    //clearTabOutput();
 
     m_pacmanExec = new PacmanExec();
     m_pacmanExec->setSharedMemory(m_sharedMemory);
@@ -1892,9 +1943,6 @@ void MainWindow::doInstall()
     QObject::connect(m_pacmanExec, SIGNAL(finished(int, QProcess::ExitStatus)),
                      this, SLOT( pacmanProcessFinished(int, QProcess::ExitStatus) ));
 
-    //QObject::connect(m_pacmanExec, SIGNAL(percentage(int)), this, SLOT(incrementPercentage(int)));
-    //QObject::connect(m_pacmanExec, SIGNAL(textToPrintExt(QString)), this, SLOT(outputText(QString)));
-    //QObject::connect(m_pacmanExec, SIGNAL(canStopTransaction(bool)), this, SLOT(onCanStopTransaction(bool)));
     QObject::connect(m_pacmanExec, SIGNAL(commandToExecInQTermWidget(QString)), this, SLOT(onExecCommandInTabTerminal(QString)));
 
     m_commandExecuting = ectn_RUN_IN_TERMINAL;
@@ -2123,6 +2171,8 @@ void MainWindow::toggleTransactionActions(const bool value)
   }
 
   m_actionPackageInfo->setEnabled(value);
+  ui->actionAddToIgnored->setEnabled(value);
+  ui->actionRemoveFromIgnored->setEnabled(value);
   ui->actionFindFileInPackage->setEnabled(value);
   ui->actionInstall->setEnabled(value);
   ui->actionInstallGroup->setEnabled(value);
@@ -2140,12 +2190,11 @@ void MainWindow::toggleTransactionActions(const bool value)
   ui->actionPacmanLogViewer->setEnabled(value);
   ui->actionCacheCleaner->setEnabled(value);
   ui->actionRepositoryEditor->setEnabled(value);
+  m_actionPacmanKey->setEnabled(value);
   m_actionSysInfo->setEnabled(value);
 
   if (value && m_initializationCompleted) m_actionSwitchToForeignTool->setEnabled(value);
 
-  //ui->actionGetNews->setEnabled(value);
-
   if (!isAURGroupSelected())
   {
     ui->actionInstallLocalPackage->setEnabled(value);
@@ -2168,6 +2217,7 @@ void MainWindow::toggleTransactionActions(const bool value)
 
   //View menu
   ui->actionViewAllPackages->setEnabled(value);
+  ui->actionViewIgnoredPackages->setEnabled(value);
   ui->actionViewInstalledPackages->setEnabled(value);
   ui->actionViewNonInstalledPackages->setEnabled(value);
   ui->actionViewOutdated->setEnabled(value);
@@ -2204,14 +2254,6 @@ void MainWindow::toggleSystemActions(const bool value)
     }
   }
 
-  /*if (isAURGroupSelected() && Package::getForeignRepositoryToolName() == ctn_KCP_TOOL)
-  {
-    ui->actionCheckUpdates->setEnabled(true);
-  }*;
-  else if (Package::getForeignRepositoryToolName() != ctn_KCP_TOOL)
-  {
-    ui->actionCheckUpdates->setEnabled(value);
-  }*/
   if (!isAURGroupSelected())
   {
     m_actionMenuOptions->setEnabled(value);
@@ -2453,8 +2495,15 @@ void MainWindow::pacmanProcessFinished(int exitCode, QProcess::ExitStatus exitSt
       }
       else if (m_commandExecuting != ectn_MIRROR_CHECK && m_commandExecuting != ectn_CHECK_UPDATES)
       {
+        //The user wants to go to "Display All groups"
+        if (!isAllGroupsSelected())
+        {
+          //disconnect(ui->twGroups, SIGNAL(itemSelectionChanged()), this, SLOT(onPackageGroupChanged()));
+          ui->twGroups->setCurrentItem(m_AllGroupsItem);
+          //connect(ui->twGroups, SIGNAL(itemSelectionChanged()), this, SLOT(onPackageGroupChanged()));
+        }
         //If we are in a package group, maybe we have installed/removed something, so...
-        if (!isAURGroupSelected())
+        else if (!isAURGroupSelected())
         {
           metaBuildPackageList();
         }
