@@ -35,6 +35,8 @@
 #include <QDesktopServices>
 #include <QFontDatabase>
 
+#include <QDebug>
+
 //#include <QDebug>
 
 /*
@@ -159,6 +161,7 @@ void OptionsDialog::initialize(){
   m_backendHasChanged = false;
   m_iconHasChanged = false;
 
+  initListIcons();
   initButtonBox();
   initGeneralTab();
   initPackageListTab();
@@ -176,15 +179,36 @@ void OptionsDialog::initialize(){
 
   if (m_calledByOctopi && !UnixCommand::isOctoToolRunning(QLatin1String("octopi-notifier")))
   {
-    removeTabByName(tr("Updates"));
+    removeTabByName(QStringLiteral("Updates"));
   }
   else if (!UnixCommand::isOctoToolRunning(QLatin1String("octopi")))
   {
-    removeTabByName(tr("Backend"));
-    removeTabByName(tr("Package List"));
+    removeTabByName(QStringLiteral("Backend"));
+    removeTabByName(QStringLiteral("Package List"));
   }
 
-  tabWidget->setCurrentIndex(0);
+  connect(listIcons, &QListWidget::currentRowChanged, this, &OptionsDialog::setStackedWidgetIndex);
+  listIcons->setCurrentRow(0);
+}
+
+void OptionsDialog::initListIcons()
+{
+  listIcons->addItem(tr("General"));
+  listIcons->addItem(tr("Backend"));
+  listIcons->addItem(tr("Package List"));
+  listIcons->addItem(QStringLiteral("AUR"));
+  listIcons->addItem(tr("Icon"));
+  listIcons->addItem(tr("Updates"));
+  listIcons->addItem(tr("Terminal"));
+
+  listIcons->setIconSize(QSize(24, 24));
+  listIcons->item(0)->setIcon(IconHelper::getIconWindow());
+  listIcons->item(1)->setIcon(IconHelper::getIconPacman());
+  listIcons->item(2)->setIcon(IconHelper::getIconMenu());
+  listIcons->item(3)->setIcon(IconHelper::getIconForeignGreen());
+  listIcons->item(4)->setIcon(IconHelper::getIconOctopi());
+  listIcons->item(5)->setIcon(IconHelper::getIconCheckUpdates());
+  listIcons->item(6)->setIcon(IconHelper::getIconTerminal2());
 }
 
 void OptionsDialog::initButtonBox(){
@@ -206,7 +230,6 @@ void OptionsDialog::initGeneralTab()
   cbShowStopTransaction->setChecked(SettingsManager::getShowStopTransaction());
   cbConfirmationDialogInSysUpgrade->setChecked(SettingsManager::getEnableConfirmationDialogInSysUpgrade());
   cbEnableInternetCheck->setChecked(SettingsManager::getEnableInternetChecking());  
-  cbPlayBellSound->setChecked(SettingsManager::getPlayBellSoundOnTerminalPasswordInput());
   gbInternetChecking->setStyleSheet(QLatin1String("border: 0;"));
 
   if (SettingsManager::getInternetCheckingDomain().contains(QLatin1String("baidu")))
@@ -231,12 +254,47 @@ void OptionsDialog::enableDisableGroupBoxInternetCheck()
   }
 }
 
+void OptionsDialog::setStackedWidgetIndex(int index)
+{
+  QIcon icon = listIcons->item(index)->icon();
+
+  if (icon.pixmap(24,24).toImage() == IconHelper::getIconWindow().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(0));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconPacman().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(3));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconMenu().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(1));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconForeignGreen().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(2));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconOctopi().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(4));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconCheckUpdates().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(5));
+  }
+  else if (icon.pixmap(24,24).toImage() == IconHelper::getIconTerminal2().pixmap(24,24).toImage())
+  {
+    stackedWidget->setCurrentWidget(stackedWidget->widget(6));
+  }
+}
+
 /*
  * Initializes Package List tab
  */
 void OptionsDialog::initPackageListTab()
 {
   cbUseAlternateRowColor->setChecked(SettingsManager::getUseAlternateRowColor());
+  cbEnablePackageTooltips->setChecked(SettingsManager::getEnablePackageTooltips());
   cbShowLicensesColumn->setChecked(SettingsManager::getShowPackageLicensesColumn());
   cbShowInstalledSizeColumn->setChecked(SettingsManager::getShowPackageInstalledSizeColumn());
   cbShowBuildDateColumn->setChecked(SettingsManager::getShowPackageBuildDateColumn());
@@ -249,6 +307,8 @@ void OptionsDialog::initPackageListTab()
  */
 void OptionsDialog::initAURTab()
 {
+  gbAURVoting->setStyleSheet(QStringLiteral("border:none"));
+
   cbEditMenu->setEnabled(false);
   cbOverwrite->setChecked(false);
   cbOverwrite->setEnabled(false);
@@ -303,7 +363,7 @@ void OptionsDialog::initAURTab()
     else if (comboAUR->currentText() == ctn_PARU_TOOL)
     {
       cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-      cbNoEdit->setChecked(false); //SettingsManager::getAURNoEditParam());
+      cbNoEdit->setChecked(false);
     }
 
     cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
@@ -444,8 +504,18 @@ void OptionsDialog::initTerminalTab()
     cbFontFamily->addItem(family);
   }
 
+  if (QFile::exists(ctn_BASH_SHELL))
+  {
+    cbForceBashShell->setChecked(SettingsManager::getTerminalForceBashShell());
+  }
+  else
+  {
+    cbForceBashShell->setEnabled(false);
+  }
+
   cbFontFamily->setCurrentText(SettingsManager::getTerminalFontFamily());
   sbFontSize->setValue(SettingsManager::getTerminalFontPointSize());
+  cbPlayBellSound->setChecked(SettingsManager::getPlayBellSoundOnTerminalPasswordInput());
 }
 
 /*
@@ -453,12 +523,60 @@ void OptionsDialog::initTerminalTab()
  */
 void OptionsDialog::setCurrentIndexByTabName(const QString &tabName)
 {
-  for(int c=0; c<tabWidget->tabBar()->count(); c++)
+  if (tabName == QStringLiteral("General"))
   {
-    if (tabWidget->tabText(c) == tabName)
+    for (int i=0; i < listIcons->count(); ++i)
     {
-      tabWidget->setCurrentIndex(c);
-      break;
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconWindow().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("Backend"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconPacman().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("Package List"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconMenu().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("AUR"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconForeignGreen().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("Icon"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconOctopi().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("Updates"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconCheckUpdates().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
+    }
+  }
+  else if (tabName == QStringLiteral("Terminal"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconTerminal2().pixmap(24,24).toImage())
+        listIcons->setCurrentRow(i);
     }
   }
 }
@@ -511,10 +629,6 @@ void OptionsDialog::accept()
   {
     SettingsManager::setEnableInternetChecking(cbEnableInternetCheck->isChecked());
   }
-  if (cbPlayBellSound->isChecked() != SettingsManager::getPlayBellSoundOnTerminalPasswordInput())
-  {
-    SettingsManager::setPlayBellSoundOnTerminalPasswordInput(cbPlayBellSound->isChecked());
-  }
   if (cbEnableInternetCheck->isChecked())
   {
     if (rbBaidu->isChecked())
@@ -533,6 +647,10 @@ void OptionsDialog::accept()
     SettingsManager::setUseAlternateRowColor(cbUseAlternateRowColor->isChecked());
     emit alternateRowColorsChanged();
   }
+  if (cbEnablePackageTooltips->isChecked() != SettingsManager::getEnablePackageTooltips())
+  {
+    SettingsManager::setEnablePackageTooltips(cbEnablePackageTooltips->isChecked());
+  }
   if (cbShowLicensesColumn->isChecked() != SettingsManager::getShowPackageLicensesColumn())
   {
     SettingsManager::setShowPackageLicensesColumn(cbShowLicensesColumn->isChecked());
@@ -730,7 +848,7 @@ void OptionsDialog::accept()
   if (emptyIconPath)
   {
     delete cic;
-    setCurrentIndexByTabName(tr("Icon"));
+    setCurrentIndexByTabName(QStringLiteral("Icon"));
     QMessageBox::critical(this, StrConstants::getError(), StrConstants::getErrorIconPathInfoIsNotSet());
     return;
   }
@@ -796,6 +914,12 @@ void OptionsDialog::accept()
     consoleChanged = true;
   }
 
+  if (cbForceBashShell->isEnabled() && cbForceBashShell->isChecked() != SettingsManager::getTerminalForceBashShell())
+  {
+    SettingsManager::setTerminalForceBashShell(cbForceBashShell->isChecked());
+    consoleChanged = true;
+  }
+
   if (cbFontFamily->currentText() != SettingsManager::getTerminalFontFamily())
   {
     SettingsManager::setTerminalFontFamily(cbFontFamily->currentText());
@@ -808,6 +932,11 @@ void OptionsDialog::accept()
     consoleChanged = true;
   }
 
+  if (cbPlayBellSound->isChecked() != SettingsManager::getPlayBellSoundOnTerminalPasswordInput())
+  {
+    SettingsManager::setPlayBellSoundOnTerminalPasswordInput(cbPlayBellSound->isChecked());
+  }
+
   Options::result res=0;
 
   if (m_iconHasChanged)
@@ -831,10 +960,61 @@ void OptionsDialog::accept()
 
 void OptionsDialog::removeTabByName(const QString &tabName)
 {
-  for (int i=0; i < tabWidget->count(); ++i)
+  if (tabName == QStringLiteral("General"))
   {
-    if (tabWidget->tabText(i) == tabName)
-      tabWidget->removeTab(i);
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconWindow().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("Backend"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconPacman().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("Package List"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconMenu().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("AUR"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconForeignGreen().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("Icon"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconOctopi().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("Updates"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconCheckUpdates().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
+  }
+  else if (tabName == QStringLiteral("Terminal"))
+  {
+    for (int i=0; i < listIcons->count(); ++i)
+    {
+      if (listIcons->item(i)->icon().pixmap(24,24).toImage() == IconHelper::getIconTerminal2().pixmap(24,24).toImage())
+        listIcons->item(i)->setHidden(true);
+    }
   }
 }
 
@@ -897,7 +1077,72 @@ void OptionsDialog::comboAURChanged(const QString &text)
 {
   cbEditMenu->setEnabled(false);
 
-  if (text == ctn_NO_AUR_TOOL)
+  if (text != ctn_NO_AUR_TOOL)
+  {
+    leAURBuildDir->setEnabled(true);
+    bSelAURBuildDir->setEnabled(true);
+    bClearAURBuildDir->setEnabled(true);
+
+    if (text == ctn_PACAUR_TOOL)
+    {
+      cbOverwrite->setChecked(false);
+      cbOverwrite->setEnabled(false);
+      cbNoConfirm->setEnabled(true);
+      cbNoEdit->setEnabled(true);
+      cbSearchOutdatedAURPackages->setEnabled(true);
+      cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
+      cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+      cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    }
+    else if (text == ctn_PIKAUR_TOOL)
+    {
+      cbOverwrite->setChecked(false);
+      cbOverwrite->setEnabled(false);
+      cbNoConfirm->setEnabled(true);
+      cbNoEdit->setEnabled(true);
+      cbSearchOutdatedAURPackages->setEnabled(true);
+      cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
+      cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+      cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    }
+    else if (text == ctn_TRIZEN_TOOL)
+    {
+      cbOverwrite->setChecked(false);
+      cbOverwrite->setEnabled(false);
+      cbNoConfirm->setEnabled(true);
+      cbNoEdit->setEnabled(true);
+      cbSearchOutdatedAURPackages->setEnabled(true);
+      cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
+      cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+      cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    }
+    else if (text == ctn_YAY_TOOL)
+    {
+      cbEditMenu->setEnabled(true);
+      cbOverwrite->setEnabled(true);
+      cbOverwrite->setChecked(SettingsManager::getAUROverwriteParam());
+      cbNoConfirm->setEnabled(true);
+      cbNoEdit->setEnabled(true);
+      cbSearchOutdatedAURPackages->setEnabled(true);
+      cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
+      cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
+      cbEditMenu->setChecked(SettingsManager::getAUREditMenuParam());
+
+      cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    }
+    else if (text == ctn_PARU_TOOL)
+    {
+      cbOverwrite->setChecked(false);
+      cbOverwrite->setEnabled(false);
+      cbNoConfirm->setEnabled(true);
+      cbNoEdit->setEnabled(false);
+      cbSearchOutdatedAURPackages->setEnabled(true);
+      cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
+      cbNoEdit->setChecked(false);
+      cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    }
+  }
+  else
   {
     cbOverwrite->setChecked(false);
     cbOverwrite->setEnabled(false);
@@ -907,64 +1152,9 @@ void OptionsDialog::comboAURChanged(const QString &text)
     cbNoEdit->setEnabled(false);
     cbSearchOutdatedAURPackages->setChecked(false);
     cbSearchOutdatedAURPackages->setEnabled(false);
-  }
-  else if (text == ctn_PACAUR_TOOL)
-  {
-    cbOverwrite->setChecked(false);
-    cbOverwrite->setEnabled(false);
-    cbNoConfirm->setEnabled(true);
-    cbNoEdit->setEnabled(true);
-    cbSearchOutdatedAURPackages->setEnabled(true);
-    cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-    cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
-    cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
-  }
-  else if (text == ctn_PIKAUR_TOOL)
-  {
-    cbOverwrite->setChecked(false);
-    cbOverwrite->setEnabled(false);
-    cbNoConfirm->setEnabled(true);
-    cbNoEdit->setEnabled(true);
-    cbSearchOutdatedAURPackages->setEnabled(true);
-    cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-    cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
-    cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
-  }
-  else if (text == ctn_TRIZEN_TOOL)
-  {
-    cbOverwrite->setChecked(false);
-    cbOverwrite->setEnabled(false);
-    cbNoConfirm->setEnabled(true);
-    cbNoEdit->setEnabled(true);
-    cbSearchOutdatedAURPackages->setEnabled(true);
-    cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-    cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
-    cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
-  }
-  else if (text == ctn_YAY_TOOL)
-  {
-    cbEditMenu->setEnabled(true);
-    cbOverwrite->setEnabled(true);
-    cbOverwrite->setChecked(SettingsManager::getAUROverwriteParam());
-    cbNoConfirm->setEnabled(true);
-    cbNoEdit->setEnabled(true);
-    cbSearchOutdatedAURPackages->setEnabled(true);
-    cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-    cbNoEdit->setChecked(SettingsManager::getAURNoEditParam());
-    cbEditMenu->setChecked(SettingsManager::getAUREditMenuParam());
-
-    cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
-  }
-  else if (text == ctn_PARU_TOOL)
-  {
-    cbOverwrite->setChecked(false);
-    cbOverwrite->setEnabled(false);
-    cbNoConfirm->setEnabled(true);
-    cbNoEdit->setEnabled(false);
-    cbSearchOutdatedAURPackages->setEnabled(true);
-    cbNoConfirm->setChecked(SettingsManager::getAURNoConfirmParam());
-    cbNoEdit->setChecked(false);
-    cbSearchOutdatedAURPackages->setChecked(SettingsManager::getSearchOutdatedAURPackages());
+    leAURBuildDir->setEnabled(false);
+    bSelAURBuildDir->setEnabled(false);
+    bClearAURBuildDir->setEnabled(false);
   }
 }
 
@@ -1000,7 +1190,7 @@ void OptionsDialog::onAURConnect()
     if (v.isPkgVoted(QStringLiteral("octopi-dev"))==0) octopiDevVoted=true;
     if (v.isPkgVoted(QStringLiteral("octopi"))==0) octopiVoted=true;
     if (v.isPkgVoted(QStringLiteral("alpm_octopi_utils"))==0) alpmUtilsVoted=true;
-    if (v.isPkgVoted(QStringLiteral("qt-sudo"))==0) alpmUtilsVoted=true;
+    if (v.isPkgVoted(QStringLiteral("qt-sudo"))==0) qtsudoVoted=true;
 
     if (octopiDevVoted && octopiVoted && alpmUtilsVoted)
     {
