@@ -33,6 +33,7 @@
 #include <QTextStream>
 #include <QList>
 #include <QFile>
+#include <QTemporaryFile>
 #include <QRegularExpression>
 #include <QEventLoop>
 #include <QtNetwork/QNetworkReply>
@@ -41,6 +42,128 @@
  * This class abstracts all the relevant package information and services
  */
 
+/*
+ * Return IgnorePkg list of packages from /etc/pacman.conf (if any)
+ */
+QSet<QString> *Package::extractIgnorePkgList() {
+  QSet<QString> *pkgList = new QSet<QString>;
+  QFile file(QStringLiteral("/etc/pacman.conf"));
+
+  if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+    //qWarning() << "Error opening file";
+    return pkgList;
+  }
+
+  QTextStream in(&file);
+
+  while (!in.atEnd()) {
+    QString line = in.readLine().trimmed();
+
+    if (line.isEmpty())
+      continue;
+
+    if (line.startsWith(QStringLiteral("IgnorePkg")) || line.startsWith(QStringLiteral("#IgnorePkg")))
+    {
+      QStringList parts = line.split(QStringLiteral("="), Qt::SkipEmptyParts);
+      if (parts.size() < 2)
+        continue;
+
+      QString packages = parts[1].trimmed();
+      QStringList pl = packages.split(QStringLiteral(" "), Qt::SkipEmptyParts);
+      for (QString &p: pl)
+      {
+        pkgList->insert(p);
+      }
+      break;
+    }
+  }
+
+  file.close();
+  return pkgList;
+}
+
+/*
+ * Overwrites pacman config to include given ignored package list
+ */
+bool Package::updateIgnorePkgSection(const QSet<QString> *ignoredPackages)
+{
+  QStringList ignored = ignoredPackages->values();
+  ignored.sort();
+  QFile file(QStringLiteral("/etc/pacman.conf"));
+  QTemporaryFile fileAux;
+
+  if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+    //qWarning() << "Error opening file";
+    return false;
+  }
+
+  QStringList lines;
+  QTextStream in(&file);
+  bool ignorePkgFound = false;
+
+  while (!in.atEnd()) {
+    QString line = in.readLine();
+    QString trimmedLine = line.trimmed();
+
+    if (trimmedLine.startsWith(QStringLiteral("IgnorePkg")) || trimmedLine.startsWith(QStringLiteral("#IgnorePkg"))) {
+      ignorePkgFound = true;
+      QString newLine;
+
+      if (ignoredPackages->isEmpty()) {
+        newLine = QStringLiteral("#IgnorePkg =");
+      } else {
+        newLine = QStringLiteral("IgnorePkg = ") + ignored.join(QStringLiteral(" "));
+      }
+
+      // Preservar identação original
+      QString indent = line.left(line.indexOf(trimmedLine));
+      lines.append(indent + newLine);
+    } else {
+      lines.append(line);
+    }
+  }
+
+  file.close();
+
+  // Se não encontrou, adicionar ao final
+  if (!ignorePkgFound) {
+    QString newLine;
+    if (ignoredPackages->isEmpty()) {
+      newLine = QStringLiteral("#IgnorePkg =");
+    } else {
+      newLine = QStringLiteral("IgnorePkg = ") + ignored.join(QStringLiteral(" "));
+    }
+
+    lines.append(QStringLiteral(""));
+    lines.append(newLine);
+  }
+
+  QTextStream out(&fileAux);
+  if (fileAux.open())
+  {
+    for (const QString &l : lines) {
+      out << l << QStringLiteral("\n");
+      //qDebug() << QStringLiteral("Line: ") << l;
+    }
+
+    //qDebug() << fileAux.fileName();
+    fileAux.close();
+  }
+
+  //Overwrite /etc/pacman.conf file!
+  QString command =
+    QLatin1String("cp ") + fileAux.fileName() +
+      QLatin1String(" /etc/pacman.conf;") +
+      QLatin1String(" chown root /etc/pacman.conf;") +
+      QLatin1String(" chgrp root /etc/pacman.conf;") +
+      QLatin1String("chmod 644 /etc/pacman.conf");
+
+  UnixCommand unixC;
+  unixC.execCommand(command);
+
+  return true;
+}
+
 /*
  * Retrieves the basic package name, without latest "-" part
  */
@@ -525,7 +648,7 @@ QStringList *Package::getTargetRemovalList(const QString &pkgName, const QString
 /*
  *Retrieves the list of foreign packages (those installed from unknown repositories like AUR)
  */
-QList<PackageListData> *Package::getForeignPackageList()
+QList<PackageListData> *Package::getForeignPackageList(QSet<QString> *ignoredPackages)
 {
   QList<PackageListData> * res = new QList<PackageListData>();
 
@@ -540,7 +663,11 @@ QList<PackageListData> *Package::getForeignPackageList()
       if (parts.size() == 2)
       {
         QString desc=parts[0] + QLatin1String(" ") + Package::getInformationDescription(parts[0], true);
-        res->append(PackageListData(parts[0], QLatin1String(""), parts[1], desc, ectn_FOREIGN));
+
+        if (ignoredPackages->contains(parts[0]))
+          res->append(PackageListData(parts[0], QLatin1String(""), parts[1], desc, ectn_IGNORED));
+        else
+          res->append(PackageListData(parts[0], QLatin1String(""), parts[1], desc, ectn_FOREIGN));
       }
     }
   }
@@ -562,7 +689,11 @@ QList<PackageListData> *Package::getForeignPackageList()
       license=parts[6];
       installReason=parts[7];
 
-      res->append(PackageListData(parts[0], QLatin1String(""), parts[1], parts[0] + QLatin1Char(' ') + parts[2],
+      if (ignoredPackages->contains(parts[0]))
+        res->append(PackageListData(parts[0], QLatin1String(""), parts[1], parts[0] + QLatin1Char(' ') + parts[2],
+                                    instSize.toDouble(&ok), buildDate.toDouble(&ok), installDate.toDouble(&ok), license, installReason, ectn_IGNORED));
+      else
+        res->append(PackageListData(parts[0], QLatin1String(""), parts[1], parts[0] + QLatin1Char(' ') + parts[2],
           instSize.toDouble(&ok), buildDate.toDouble(&ok), installDate.toDouble(&ok), license, installReason, ectn_FOREIGN));
     }
   }
@@ -1073,6 +1204,7 @@ QList<PackageListData> *Package::getKcpPackageList(const QString &searchString,
       //First we get repository and name!
       QStringList parts = packageTuple.split(QLatin1Char(' '));
       parts[0] = parts[0].remove(QStringLiteral("[1;35m"));
+      parts[0] = parts[0].remove(QStringLiteral("[95m"));
 
       QString repoName = parts[0];
       int a = repoName.indexOf(QLatin1String("/"));
@@ -1086,6 +1218,8 @@ QList<PackageListData> *Package::getKcpPackageList(const QString &searchString,
 
       pkgRepository = StrConstants::getForeignPkgRepositoryName().toUpper();
       pkgName = repoName.mid(a+1);
+      parts[1] = parts[1].remove(QStringLiteral("[92m"));
+      parts[1] = parts[1].remove(QStringLiteral("[94m"));
       pkgVersion = parts[1];
 
       QStringList strVotes = parts.filter(QStringLiteral("("));
@@ -2288,6 +2422,8 @@ QStringList Package::getContents(const QString& pkgName, bool isInstalled)
     }
   }
 
+  //qDebug() << "... and QStringList number of lines of " << slResult.count();
+
   return slResult;
 }
 
