@@ -198,6 +198,7 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
   }
 
   bool continueTesting = false;
+  int a;
   QString perc;
   QString msg = output;
   QString progressRun;
@@ -312,7 +313,9 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
   if (msg.indexOf(progressRun) != -1 || continueTesting)
   {
     if (!continueTesting){
-      perc = msg.right(4).trimmed();
+      //perc = msg.right(4).trimmed();
+      a = msg.lastIndexOf(QLatin1String("%"));
+      perc = msg.mid(a-3, 3).trimmed() + QLatin1String("%");
       if (m_debugMode) std::cout << "percentage is: " << perc.toLatin1().data() << std::endl;
     }
 
@@ -427,6 +430,7 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
   else
   {
     //Let's supress some annoying string bugs...
+    msg.remove(QRegularExpression(QStringLiteral("^Password:")));
     msg.remove(QRegularExpression(QStringLiteral("Don't need password!!")));
     msg.remove(QRegularExpression(QStringLiteral("\\(process.+")));
     msg.remove(QRegularExpression(QStringLiteral("QXcbConnection: XCB error:.+")));
@@ -442,6 +446,7 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
     msg.remove(QRegularExpression(QStringLiteral("org\\.kde\\.")));
     msg.remove(QRegularExpression(QStringLiteral("QCommandLineParser")));
     msg.remove(QRegularExpression(QStringLiteral("QCoreApplication.+")));
+    msg.remove(QRegularExpression(QStringLiteral("Detected locale.+")));
     msg.remove(QRegularExpression(QStringLiteral("Fontconfig warning.+")));
     msg.remove(QRegularExpression(QStringLiteral("reading configurations from.+")));
     msg.remove(QRegularExpression(QStringLiteral(".+annot load library.+")));
@@ -450,6 +455,8 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
     msg.remove(QRegularExpression(QStringLiteral("(lxqt|octopi|qt)-sudo:.+")));
     msg.remove(QRegularExpression(QStringLiteral("qt.qpa.plugin:.+")));
     msg.remove(QRegularExpression(QStringLiteral("qt.qpa.xcb:.+")));
+    msg.remove(QRegularExpression(QStringLiteral("qt.qpa.wayland.+")));
+    msg.remove(QRegularExpression(QStringLiteral("\\[sudo\\] password for.+")));
     msg.remove(QRegularExpression(QStringLiteral("Icon theme \".+")));
     msg.remove(QRegularExpression(QStringLiteral("Gtk-Message:.+")));
     msg.remove(QRegularExpression(QStringLiteral("\\[K$")));
@@ -458,6 +465,8 @@ void PacmanExec::parsePacmanProcessOutput(const QString &output)
     msg.remove(QRegularExpression(QStringLiteral("libEGL warning.+")));
     msg.remove(QRegularExpression(QStringLiteral("MESA: error:.*")));
     msg.remove(QRegularExpression(QStringLiteral("^for more information\\.")));
+    msg.remove(QRegularExpression(QStringLiteral("QApplication:.+")));
+    msg.remove(QRegularExpression(QStringLiteral("Available styles:.+")));
 
     msg = msg.trimmed();
     msg.remove(QRegularExpression(QStringLiteral("Total")));
@@ -568,6 +577,8 @@ void PacmanExec::prepareTextToPrint(QString str, TreatString ts, TreatURLLinks t
     return;
   }
 
+  if (str.size() <= 3) return;
+
   //If the string waiting to be printed is from curl status OR any other unwanted string...
   if (!str.contains(QRegularExpression(QStringLiteral("<font color"))))
     if ((str.contains(QRegularExpression(QStringLiteral("\\(\\d"))) &&
@@ -585,6 +596,8 @@ void PacmanExec::prepareTextToPrint(QString str, TreatString ts, TreatURLLinks t
       return;
     }
 
+  if (str.indexOf(QLatin1String("o o")) != -1) return;
+
   if (str.indexOf(QLatin1String("%")) != -1) str.remove(QLatin1String("%"));
 
   //If the str waiting to being print has not yet been printed...
@@ -1096,9 +1109,9 @@ void PacmanExec::doInstallLocal(const QString &listOfPackages)
   {
     if(p.trimmed().isEmpty()) continue;
     if (dontUseForce)
-      command += QLatin1String("pacman -U --noconfirm \"") + p.trimmed() + QLatin1String("\";");
+      command += QLatin1String("LANG=C.UTF-8 pacman -U --noconfirm \"") + p.trimmed() + QLatin1String("\";");
     else
-      command += QLatin1String("pacman -U --force --noconfirm \"") + p.trimmed() + QLatin1String("\";");
+      command += QLatin1String("LANG=C.UTF-8 pacman -U --force --noconfirm \"") + p.trimmed() + QLatin1String("\";");
   }
 
   m_lastCommandList.clear();
@@ -1112,9 +1125,9 @@ void PacmanExec::doInstallLocal(const QString &listOfPackages)
   {
     if(p.trimmed().isEmpty()) continue;
     if (dontUseForce)
-      m_lastCommandList.append(QLatin1String("pacman -U \"") + p.trimmed() + QLatin1String("\";"));
+      m_lastCommandList.append(QLatin1String("LANG=C.UTF-8 pacman -U \"") + p.trimmed() + QLatin1String("\";"));
     else
-      m_lastCommandList.append(QLatin1String("pacman -U --force \"") + p.trimmed() + QLatin1String("\";"));
+      m_lastCommandList.append(QLatin1String("LANG=C.UTF-8 pacman -U --force \"") + p.trimmed() + QLatin1String("\";"));
   }
 
   m_lastCommandList.append(QStringLiteral("echo -e;"));
@@ -1322,10 +1335,19 @@ void PacmanExec::doSystemUpgradeInTerminal(CommandExecuting additionalCommand)
     m_lastCommandList.append(QLatin1String("rm ") + ctn_PACMAN_DATABASE_LOCK_FILE);
   }
 
-  if (additionalCommand == ectn_NONE)
-    m_lastCommandList.append(QStringLiteral("pacman -Syu"));
-  else if (additionalCommand == ectn_SYNC_DATABASE)
-    m_lastCommandList.append(QStringLiteral("pacman -Syu"));
+  bool isGarudaLinux = UnixCommand::getLinuxDistro() == ectn_GARUDALINUX;
+  // If it is Garuda, we call garuda-update, instead of ordinary pacman -Syu
+  if (isGarudaLinux)
+  {
+    m_lastCommandList.append(QStringLiteral("garuda-update"));
+  }
+  else
+  {
+    if (additionalCommand == ectn_NONE)
+      m_lastCommandList.append(QStringLiteral("pacman -Syu"));
+    else if (additionalCommand == ectn_SYNC_DATABASE)
+      m_lastCommandList.append(QStringLiteral("pacman -Syu"));
+  }
 
   m_lastCommandList.append(QStringLiteral("echo -e"));
   m_lastCommandList.append(QLatin1String("read -n 1 -p \"") + StrConstants::getPressAnyKey() + QLatin1Char('"'));
@@ -1400,6 +1422,20 @@ void PacmanExec::doAURRemoveAndInstallInTerminal(const QString &listOfPackagesto
   m_unixCommand->runCommandInTerminalAsNormalUser(m_lastCommandList);
 }
 
+/*
+ * Calls pacman-key to refresh packager gpg keys
+ */
+void PacmanExec::doRefreshPacmanKeys()
+{
+  m_lastCommandList.clear();
+  m_lastCommandList.append(QStringLiteral("/usr/bin/pacman-key --refresh-keys;"));
+  m_lastCommandList.append(QStringLiteral("echo -e;"));
+  m_lastCommandList.append(QLatin1String("read -n 1 -p \"") + StrConstants::getPressAnyKey() + QLatin1Char('"'));
+
+  m_commandExecuting = ectn_RUN_IN_TERMINAL;
+  m_unixCommand->runCommandInTerminalWithSudo(m_lastCommandList);
+}
+
 /*
  * Calls AUR tool to install given packages inside a terminal
  */
