@@ -149,7 +149,7 @@ QDateTime SettingsManager::getLastCheckUpdatesTime()
 {
   if (!instance()->getSYSsettings()->contains(ctn_KEY_LAST_CHECKUPDATES_TIME))
   {
-    return QDateTime();
+    return QDateTime::currentDateTime().addDays(-2);
   }
   else
   {
@@ -180,8 +180,9 @@ void SettingsManager::setLastCheckUpdatesTime(QDateTime newValue)
 
 //Octopi related --------------------------------------------------------------------
 int SettingsManager::getCurrentTabIndex(){
+  //Let Help tab be the first to be shown when Octopi runs for the 1st time
   return instance()->getSYSsettings()->value(
-        ctn_KEY_CURRENT_TAB_INDEX, 0).toInt();
+        ctn_KEY_CURRENT_TAB_INDEX, ctn_TABINDEX_HELPUSAGE).toInt();
 }
 
 int SettingsManager::getPanelOrganizing(){
@@ -189,7 +190,7 @@ int SettingsManager::getPanelOrganizing(){
 }
 
 int SettingsManager::getPackageListOrderedCol(){
-  return instance()->getSYSsettings()->value(ctn_KEY_PACKAGE_LIST_ORDERED_COL, 1 ).toInt();
+  return instance()->getSYSsettings()->value(ctn_KEY_PACKAGE_LIST_ORDERED_COL, 0 ).toInt();
 }
 
 int SettingsManager::getPackageListSortOrder(){
@@ -354,7 +355,7 @@ QString SettingsManager::getDistroRSSUrl(LinuxDistro d)
   else if (d == ectn_ENDEAVOUROS)
     return QStringLiteral("https://endeavouros.com/feed/");
   else if (d == ectn_KAOS)
-    return QStringLiteral("https://kaosx.us/feed.xml");
+    return QStringLiteral("https://kaosx.us/rss.xml");
   else if (d == ectn_MANJAROLINUX)
     return QStringLiteral("https://forum.manjaro.org/c/announcements/8.rss");
   else if (d == ectn_OBARUN)
@@ -382,7 +383,7 @@ QString SettingsManager::getDistroRSSUrl()
   else if (distro == ectn_GARUDALINUX)
     return (p_instance.getSYSsettings()->value(ctn_KEY_DISTRO_RSS_URL, QStringLiteral("https://forum.garudalinux.org/c/announcements/16.rss"))).toString();
   else if (distro == ectn_KAOS)
-    return (p_instance.getSYSsettings()->value(ctn_KEY_DISTRO_RSS_URL, QStringLiteral("https://kaosx.us/feed.xml"))).toString();
+    return (p_instance.getSYSsettings()->value(ctn_KEY_DISTRO_RSS_URL, QStringLiteral("https://kaosx.us/rss.xml"))).toString();
   else if (distro == ectn_MANJAROLINUX)
     return (p_instance.getSYSsettings()->value(ctn_KEY_DISTRO_RSS_URL, QStringLiteral("https://forum.manjaro.org/c/announcements/8.rss"))).toString();
   else if (distro == ectn_OBARUN)
@@ -459,7 +460,7 @@ QString SettingsManager::getAURTool()
     if (getAURNoConfirmParam()) params += QLatin1String(" --noconfirm ");
     if (getAURNoEditParam()) params += QLatin1String(" --editmenu=false ");
     if (getAUREditMenuParam()) params += QLatin1String(" --editmenu ");
-    if (getAUROverwriteParam()) params += QLatin1String(" --overwrite=\"*\" ");
+    if (getAUROverwriteParam()) params += QLatin1String(" --overwrite=\\\"*\\\" ");
     ret += params;
   }
   else if (ret == ctn_PARU_TOOL)
@@ -493,7 +494,7 @@ QString SettingsManager::getAURTool()
     {
       if (getAURNoConfirmParam()) params += QLatin1String(" --noconfirm ");
       if (getAURNoEditParam()) params += QLatin1String(" --editmenu=false ");
-      if (getAUROverwriteParam()) params += QLatin1String(" --overwrite=\"*\" ");
+      if (getAUROverwriteParam()) params += QLatin1String(" --overwrite=\\\"*\\\" ");
 
       p_instance.setAURTool(ctn_YAY_TOOL);
       p_instance.getSYSsettings()->sync();
@@ -587,6 +588,16 @@ bool SettingsManager::getEnableAURVoting()
   return (p_instance.getSYSsettings()->value(ctn_KEY_ENABLE_AUR_VOTING, false)).toBool();
 }
 
+bool SettingsManager::getEnablePackageTooltips()
+{
+  SettingsManager p_instance;
+
+  if (UnixCommand::isCachyOS())
+    return (p_instance.getSYSsettings()->value(ctn_KEY_ENABLE_PACKAGE_TOOLTIPS, false)).toBool();
+  else
+    return (p_instance.getSYSsettings()->value(ctn_KEY_ENABLE_PACKAGE_TOOLTIPS, true)).toBool();
+}
+
 QString SettingsManager::getAURUserName()
 {
   SettingsManager p_instance;
@@ -646,6 +657,12 @@ bool SettingsManager::getPlayBellSoundOnTerminalPasswordInput()
   return (p_instance.getSYSsettings()->value(ctn_KEY_PLAY_BELL_SOUND_ON_TERMINAL_PASSWORD_INPUT, false)).toBool();
 }
 
+uint SettingsManager::getSearchMethod()
+{
+  SettingsManager p_instance;
+  return (p_instance.getSYSsettings()->value(ctn_KEY_SEARCH_METHOD, ectn_SEARCH_BY_NAME)).toUInt();
+}
+
 int SettingsManager::getConsoleFontSize()
 {
   SettingsManager p_instance;
@@ -668,10 +685,6 @@ QString SettingsManager::getSUTool()
 
 bool SettingsManager::getShowGroupsPanel()
 {
-  if (!instance()->getSYSsettings()->contains(ctn_KEY_SHOW_GROUPS_PANEL)){
-    instance()->getSYSsettings()->setValue(ctn_KEY_SHOW_GROUPS_PANEL, true);
-  }
-
   return (instance()->getSYSsettings()->value(ctn_KEY_SHOW_GROUPS_PANEL, false)).toBool();
 }
 
@@ -718,6 +731,11 @@ qreal SettingsManager::getTerminalFontPointSize()
   return (instance()->getSYSsettings()->value(ctn_KEY_TERMINAL_FONT_POINT_SIZE, 10.0)).toReal();
 }
 
+bool SettingsManager::getTerminalForceBashShell()
+{
+  return (instance()->getSYSsettings()->value(ctn_KEY_TERMINAL_FORCE_BASH_SHELL, true)).toBool();
+}
+
 QByteArray SettingsManager::getWindowSize(){
   return (instance()->getSYSsettings()->value(ctn_KEY_WINDOW_SIZE, 0).toByteArray());
 }
@@ -744,7 +762,11 @@ QByteArray SettingsManager::getSplitterHorizontalState(){
 bool SettingsManager::isInstantSearchSelected()
 {
   SettingsManager p_instance;
-  return (p_instance.getSYSsettings()->value(ctn_KEY_INSTANT_SEARCH, true)).toBool();
+
+  if (UnixCommand::isCachyOS())
+    return (p_instance.getSYSsettings()->value(ctn_KEY_INSTANT_SEARCH, false)).toBool();
+  else
+    return (p_instance.getSYSsettings()->value(ctn_KEY_INSTANT_SEARCH, true)).toBool();
 }
 
 void SettingsManager::setCurrentTabIndex(int newValue){
@@ -1028,6 +1050,12 @@ void SettingsManager::setEnableAURVoting(bool newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setEnablePackageTooltips(bool newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_ENABLE_PACKAGE_TOOLTIPS, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 void SettingsManager::setAURUserName(const QString &newValue)
 {
   instance()->getSYSsettings()->setValue(ctn_KEY_AUR_USERNAME, newValue);
@@ -1119,10 +1147,22 @@ void SettingsManager::setTerminalFontPointSize(qreal newValue)
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setTerminalForceBashShell(bool newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_TERMINAL_FORCE_BASH_SHELL, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 void SettingsManager::setPlayBellSoundOnTerminalPasswordInput(bool newValue)
 {
   instance()->getSYSsettings()->setValue(ctn_KEY_PLAY_BELL_SOUND_ON_TERMINAL_PASSWORD_INPUT, newValue);
   instance()->getSYSsettings()->sync();
 }
 
+void SettingsManager::setSearchMethod(SearchMethod newValue)
+{
+  instance()->getSYSsettings()->setValue(ctn_KEY_SEARCH_METHOD, newValue);
+  instance()->getSYSsettings()->sync();
+}
+
 //Octopi related --------------------------------------------------------------------
