@@ -23,6 +23,8 @@
 #include "wmhelper.h"
 #include "terminal.h"
 #include <iostream>
+#include <unistd.h>
+#include "limits.h"
 
 #include <QProcess>
 #include <QRegularExpression>
@@ -230,7 +232,6 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
   QStringList sl;
 
   QString tool = Package::getForeignRepositoryToolNameParam();
-  std::cout << "Tool incialmente: " << tool.toLatin1().data() << std::endl;
 
   if (tool.contains(QLatin1String("--noconfirm")))
   {
@@ -262,10 +263,10 @@ QByteArray UnixCommand::getAURPackageList(const QString &searchString)
     sl << QLatin1String("--noedit");
     tool = tool.trimmed();
   }
-  if (tool.contains(QLatin1String("--overwrite=\"*\"")))
+  if (tool.contains(QLatin1String("--overwrite=\\\"*\\\"")))
   {
-    tool.remove(QLatin1String("--overwrite=\"*\""));
-    sl << QLatin1String("--overwrite=\"*\"");
+    tool.remove(QLatin1String("--overwrite=\\\"*\\\""));
+    sl << QLatin1String("--overwrite=\\\"*\\\"");
     tool = tool.trimmed();
   }
 
@@ -483,6 +484,9 @@ QByteArray UnixCommand::getPackageContentsUsingPacman(const QString& pkgName, bo
 
   args << pkgName;
   QByteArray res = performQuery(args);
+
+  //qDebug() << pkgName << " has QByteArray size of " << res.size();
+  //if (res.size() > 100000) res = QByteArray();
   return res;
 }
 
@@ -845,10 +849,10 @@ QByteArray UnixCommand::execCommandAsNormalUserExt(const QString &pCommand)
 void UnixCommand::execCommand(const QString &pCommand)
 {
   QProcess p;
-  QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+  /*QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
   env.insert(QStringLiteral("LANG"), QStringLiteral("C.UTF-8"));
   env.insert(QStringLiteral("LC_MESSAGES"), QStringLiteral("C.UTF-8"));
-  p.setProcessEnvironment(env);
+  p.setProcessEnvironment(env);*/
   QStringList sl;
   sl << getShell();
   sl << QLatin1String("-c");
@@ -971,6 +975,10 @@ void UnixCommand::runCommandInTerminalWithSudo(const QString& command){
   m_terminal->runCommandInTerminalWithSudo(command);
 }
 
+void UnixCommand::runCommandInTerminalWithSudo(const QStringList& commandList){
+  m_terminal->runCommandInTerminalWithSudo(commandList);
+}
+
 /*
  * Executes given commandList as root inside a terminal using "octopi-helper -t" (passing cmds thru memory)
  */
@@ -997,10 +1005,10 @@ void UnixCommand::executeCommand(const QString &pCommand)
 {
   //COLUMNS variable code!
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-  env.remove(QStringLiteral("LANG"));
+  /*env.remove(QStringLiteral("LANG"));
   env.remove(QStringLiteral("LC_MESSAGES"));
   env.insert(QStringLiteral("LANG"), QStringLiteral("C.UTF-8"));
-  env.insert(QStringLiteral("LC_MESSAGES"), QStringLiteral("C.UTF-8"));
+  env.insert(QStringLiteral("LC_MESSAGES"), QStringLiteral("C.UTF-8"));*/
   env.remove(QStringLiteral("COLUMNS"));
   env.insert(QStringLiteral("COLUMNS"), QStringLiteral("132"));
   m_process->setProcessEnvironment(env);
@@ -1023,10 +1031,10 @@ void UnixCommand::executeCommandWithSharedMemHelper(const QString &pCommand, QSh
 
   //COLUMNS variable code!
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-  env.remove(QStringLiteral("LANG"));
+  /*env.remove(QStringLiteral("LANG"));
   env.remove(QStringLiteral("LC_MESSAGES"));
   env.insert(QStringLiteral("LANG"), QStringLiteral("C.UTF-8"));
-  env.insert(QStringLiteral("LC_MESSAGES"), QStringLiteral("C.UTF-8"));
+  env.insert(QStringLiteral("LC_MESSAGES"), QStringLiteral("C.UTF-8"));*/
   env.remove(QStringLiteral("COLUMNS"));
   env.insert(QStringLiteral("COLUMNS"), QStringLiteral("132"));
   m_process->setProcessEnvironment(env);
@@ -1162,34 +1170,22 @@ bool UnixCommand::isAppRunning(const QString &appName, bool justOneInstance)
 }
 
 /*
- * Checks if Octopi/Octopi-notifier, cache-cleaner, etc is being executed
+ * Checks if Octopi/Octopi-notifier, cache-cleaner, etc is being executed from /usr/bin
  */
 bool UnixCommand::isOctoToolRunning(const QString &octoToolName)
-{
-  bool res=false;
-
-  QProcess proc;
-  QStringList sl;
-  proc.setProcessEnvironment(getProcessEnvironment());
-  sl << QLatin1String("-C");
-  sl << octoToolName;
-  sl << QLatin1String("-o");
-  sl << QLatin1String("command");
-
-  proc.start(QLatin1String("/usr/bin/ps"), sl);
-  proc.waitForFinished();
-  QString out = QString::fromUtf8(proc.readAll().trimmed());
-  if (out.contains(QLatin1String("|"))) return false;
-  out=out.remove(QStringLiteral("\n"));
-  out=out.remove(QStringLiteral("COMMAND"));
-
-  if (octoToolName==QLatin1String("octopi-cachecle"))
+{  
+  char exePath[PATH_MAX];
+  ssize_t count = readlink("/proc/self/exe", exePath, sizeof(exePath));
+  if (count == -1)
   {
-    if (out == QLatin1String("/usr/bin/octopi-cachecleaner")) res=true;
+    //perror("readlink");
+    return false;
   }
-  else if ((out == QLatin1String("/usr/bin/") + octoToolName) || out.contains(QLatin1String("/usr/bin/") + octoToolName + QLatin1Char(' '))) res=true;
 
-  return res;
+  QString path = QString::fromUtf8(exePath, count);
+  QFileInfo fi(path);
+
+  return (fi.absoluteFilePath() == QLatin1String("/usr/bin/") + octoToolName);
 }
 
 /*
@@ -1418,6 +1414,38 @@ LinuxDistro UnixCommand::getLinuxDistro()
   return ret;
 }
 
+/*
+ * Tests if Octopi is running a CachyOS system
+ */
+bool UnixCommand::isCachyOS()
+{
+  static bool ret = false;
+  static bool firstTime = true;
+
+  if (firstTime)
+  {
+    if (QFile::exists(QStringLiteral("/etc/os-release")))
+    {
+      QFile file(QStringLiteral("/etc/os-release"));
+
+      if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+        ret = false;
+
+      QString contents = QString::fromUtf8(file.readAll());
+
+      if (contents.contains(QRegularExpression(QStringLiteral("CachyOS"))))
+      {
+        ret = true;
+      }
+      firstTime = false;
+
+      file.close();
+    }
+  }
+
+  return ret;
+}
+
 /*
  * Returns the PrettyName info from /etc/os-release
  */
